.. include:: _applications.rst


Streamlink Applications
=======================


Streamlink Twitch GUI
---------------------

.. image:: https://user-images.githubusercontent.com/467294/28097570-3415020e-66b1-11e7-928d-4b9da35daf13.jpg
    :alt: Streamlink Twitch GUI

:Description: A multi platform Twitch.tv browser for Streamlink
:Type: Graphical User Interface
:OS: |Windows| |MacOS| |Linux|
:Author: `Sebastian Meyer <https://github.com/bastimeyer>`_
:Website: https://streamlink.github.io/streamlink-twitch-gui
:Source code: https://github.com/streamlink/streamlink-twitch-gui
:Info: A NW.js based desktop web application, formerly known as *Livestreamer Twitch GUI*. Browse Twitch.tv and watch
    multiple streams at once. Filter streams by language, receive desktop notifications when followed channels start
    streaming and access the Twitch chat by using customizable chat applications.
